import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Icon, Modal, notification } from 'antd'

import MenuUtils from '@/utils/utils-custom.js'
import MKEmitter from '@/utils/events.js'
import asyncComponent from '@/utils/asyncComponent'
import './index.scss'

const PasteForm = asyncComponent(() => import('@/templates/zshare/pasteform'))

class PasteGroup extends Component {
  static propTpyes = {
    Tab: PropTypes.any,         // 标签
    insert: PropTypes.func
  }

  state = {
    visible: false
  }

  handleMenuClick = () => {
    this.setState({visible: true})
  }

  resetconfig = (item, Tab, copyBtns) => {
    item.floor = Tab.floor + 1
    item.tabId = Tab.uuid
    item.parentId = Tab.parentId
    
    if (item.type === 'tabs') {
      item.uuid = MenuUtils.getuuid()
      item.setting.name = item.setting.name + MenuUtils.getdataName().toUpperCase().substr(-4)
      item.name = item.setting.name
      
      item.subtabs.forEach(tab => {
        tab.uuid = MenuUtils.getuuid()
        tab.parentId = item.uuid

        if (item.floor >= 3) {
          tab.components = tab.components.filter(cell => cell.type !== 'tabs')
        }

        tab.components = tab.components.map(cell => {
          cell = this.resetconfig(cell, tab, copyBtns)
          return cell
        })
      })
    } else if (item.type === 'group') {
      item.uuid = MenuUtils.getuuid()
      item.setting.name = item.setting.name + MenuUtils.getdataName().toUpperCase().substr(-4)
      item.name = item.setting.name

      item.components = item.components.map(cell => {
        cell.floor = Tab.floor + 1
        cell.tabId = Tab.uuid
        cell.parentId = Tab.parentId

        cell = MenuUtils.resetComponentConfig(cell, copyBtns)

        return cell
      })
    } else {
      item = MenuUtils.resetComponentConfig(item, copyBtns)
    }

    return item
  }

  pasteSubmit = () => {
    const { Tab } = this.props
    let options = ['tabs', 'group', 'datacard', 'propcard', 'balcony', 'normaltable', 'mainsearch', 'stepform', 'tabform', 'tablecard', 'line', 'bar', 'pie', 'dashboard', 'scatter']
    let types = {
      login: '登录',
      navbar: '导航栏',
      topbar: '导航栏'
    }

    if (sessionStorage.getItem('appType') === 'mob') {
      options.push('menubar')
    }

    this.pasteFormRef.handleConfirm().then(res => {
      if (res.copyType && types[res.copyType]) {
        notification.warning({
          top: 92,
          message: '分组中不可添加《' + types[res.copyType] + '》组件！',
          duration: 5
        })
        return
      } else if (!options.includes(res.copyType)) {
        notification.warning({
          top: 92,
          message: '配置信息格式错误！',
          duration: 5
        })
        return
      }

      let copyBtns = new Map()

      res = this.resetconfig(res, Tab, copyBtns)

      delete res.copyType
      
      this.props.insert(res, Tab)

      copyBtns = [...copyBtns.values()]

      if (copyBtns.length > 0) {
        MKEmitter.emit('copyButtons', copyBtns)
      }

      this.setState({visible: false})

      notification.success({
        top: 92,
        message: '粘贴成功！',
        duration: 2
      })
    })
  }

  render() {
    const { visible } = this.state

    return (
      <div style={{display: 'inline-block'}}>
        <Icon type="snippets" style={{color: 'purple'}} onClick={() => {this.setState({visible: true})}} />
        <Modal
          title="粘贴"
          visible={visible}
          width={600}
          maskClosable={false}
          onOk={this.pasteSubmit}
          onCancel={() => {this.setState({visible: false})}}
          destroyOnClose
        >
          <PasteForm wrappedComponentRef={(inst) => this.pasteFormRef = inst} inputSubmit={this.pasteSubmit}/>
        </Modal>
      </div>
    )
  }
}

export default PasteGroup